<?php

namespace AuthStack\Driver\AUDGeneric\App\Middleware;

use Closure;
use Illuminate\Http\Request;

class AUD
{
    public function handle(Request $request, Closure $next)
    {
        $request->headers->get('token', env('AUD_DRIVER_KEY'));

        return $next($request);
    }
}