@extends('aud::password.layout')

@section('title', 'AuthStack &ndash; Forgot Password')

@section('content')
    <h2>Please enter your username and we will send you a recovery link.</h2>

    <form method="POST" action="{{ route('aud.password.forgot') }}">

        <div class="form-group row">
            <label for="username" class="col-md-4 col-form-label text-md-right">Username</label>

            <div class="col-md-6">
                <input id="username" type="text" name="username" required>
            </div>
        </div>

        <div class="form-group row mb-0">
            <div class="col-md-6 offset-md-4">
                <input type="submit" value="Send recovery link" >
            </div>
        </div>
    </form>
@endsection